
'''
This file is automatically generated by setup.py, So don't edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.12.1',
    'branch_nick': '(detached',
    'revision_id': '3e3099cb8047dc2ddb0c7592c597136b5e45a793',
    'revno': 5177
}
